@@ -1046,7 +1046,8 @@ class ConstraintFactory(object):
         for CC in self.CONSTRAINT_CLASSES:
             try:
                 c = CC(*args, **kwargs)
-                if hasattr(c, "code"): c.code = self.get_next_code()
+                if hasattr(c, "code") and c.code == "A":
+                    c.code = self.get_next_code()
                 return c
             except TypeError, e:
                 pass
