@@ -583,7 +583,7 @@ class ResultRow(object):
         for view in self.views:
            short_form = re.sub("^[^.]+.", "", view)
            value = self[view]
-           parts.append(short_form + "=" + str(value))
+           parts.append(short_form + "=" + repr(value))
         return " ".join(parts)
 
     def __getitem__(self, key):
