@@ -9,7 +9,7 @@ q.description = 'a query made out of pythons'
 q.add_view("Gene.name Gene.symbol")
 q.add_constraint('Gene', 'LOOKUP', 'eve')
 q.add_constraint('Gene.length', '>', 50000)
-q.add_constraint('Gene', 'Clone')
+q.add_constraint('Gene', 'CDNAClone')
 q.add_constraint('Gene.symbol', 'ONE OF', ['eve', 'zen'])
 q.add_join('Gene.alleles')
 q.add_path_description('Gene', 'One of those gene-y things')
