@@ -220,6 +220,13 @@ class TestQuery(WebserviceTest): # pragma: no cover
 
     CONSTRAINTS_COUNT_3 = 2
 
+    XML_8 = '''
+        <query nampe="codesNotInOrder" model="testmodel" view="Employee.name Employee.age">
+            <constraint path="Employee.name" op="=" value="foo" code="X"/>
+            <constraint path="Employee.name" op="=" value="bar" code="Y"/>
+            <constraint path="Employee.name" op="=" value="baz" code="Z"/>
+        </query>
+          '''
 
     def setUp(self):
         if self.service is None:
@@ -266,6 +273,16 @@ class TestQuery(WebserviceTest): # pragma: no cover
         self.assertEqual(str(q7.get_sort_order()), "Department.employees.salary asc")
         self.assertEqual(len(q7.path_descriptions), 2)
 
+        q8 = self.service.new_query(xml = TestQuery.XML_8)
+        v = None
+        try:
+            v = q8.get_constraint("X").value
+        except:
+            pass
+
+        self.assertIsNotNone(v, "query should have a constraint with the code 'X', but it only has the codes: %s" % map(lambda x: x.code, q8.constraints))
+        self.assertEqual("foo", v, "And it has the right value")
+
     def testAddViews(self):
         """Queries should be able to add legal views, and complain about illegal ones"""
         self.q.add_view("Employee.age")
